@@ -52,7 +52,7 @@ def get_statistics(run_maintenance_tasks=False):
     for index, config in enumerate(QUEUES_LIST):
         queue = get_queue_by_index(index)
         connection = queue.connection
-        connection_kwargs = connection.connection_pool.connection_kwargs
+        connection_kwargs = connection.connection_pool.connection_kwargs.copy()
 
         if run_maintenance_tasks:
             clean_registries(queue)
