@@ -1,14 +1,13 @@
 from math import ceil
-from typing import Any, cast, Tuple
+from typing import Any, cast
 
 from django.contrib import admin, messages
 from django.contrib.admin.views.decorators import staff_member_required
-from django.http import Http404
+from django.http import Http404, HttpRequest, HttpResponse
 from django.shortcuts import redirect, render
 from django.urls import reverse
 from django.views.decorators.cache import never_cache
 from django.views.decorators.http import require_POST
-from redis.exceptions import ResponseError
 from rq import requeue_job
 from rq.exceptions import NoSuchJobError
 from rq.job import Job, JobStatus
@@ -29,8 +28,7 @@ from .utils import get_executions, get_jobs, stop_jobs
 
 @never_cache
 @staff_member_required
-def jobs(request, queue_index):
-    queue_index = int(queue_index)
+def jobs(request: HttpRequest, queue_index: int) -> HttpResponse:
     queue = get_queue_by_index(queue_index)
 
     items_per_page = 100
@@ -61,8 +59,7 @@ def jobs(request, queue_index):
 
 @never_cache
 @staff_member_required
-def finished_jobs(request, queue_index):
-    queue_index = int(queue_index)
+def finished_jobs(request: HttpRequest, queue_index: int) -> HttpResponse:
     queue = get_queue_by_index(queue_index)
 
     registry = FinishedJobRegistry(queue.name, queue.connection)
@@ -103,8 +100,7 @@ def finished_jobs(request, queue_index):
 
 @never_cache
 @staff_member_required
-def failed_jobs(request, queue_index):
-    queue_index = int(queue_index)
+def failed_jobs(request: HttpRequest, queue_index: int) -> HttpResponse:
     queue = get_queue_by_index(queue_index)
 
     registry = FailedJobRegistry(queue.name, queue.connection)
@@ -145,8 +141,7 @@ def failed_jobs(request, queue_index):
 
 @never_cache
 @staff_member_required
-def scheduled_jobs(request, queue_index):
-    queue_index = int(queue_index)
+def scheduled_jobs(request: HttpRequest, queue_index: int) -> HttpResponse:
     queue = get_queue_by_index(queue_index)
 
     registry = ScheduledJobRegistry(queue.name, queue.connection)
@@ -165,7 +160,7 @@ def scheduled_jobs(request, queue_index):
         last_page = int(ceil(num_jobs / items_per_page))
         page_range = list(range(1, last_page + 1))
         offset = items_per_page * (page - 1)
-        job_ids = registry.get_job_ids(offset, offset + items_per_page - 1, desc=sort_direction== 'descending')
+        job_ids = registry.get_job_ids(offset, offset + items_per_page - 1, desc=sort_direction == 'descending')
         jobs = get_jobs(queue, job_ids, registry)
         for job in jobs:
             job.scheduled_at = registry.get_scheduled_time(job)  # type: ignore[attr-defined]
@@ -187,8 +182,7 @@ def scheduled_jobs(request, queue_index):
 
 @never_cache
 @staff_member_required
-def started_jobs(request, queue_index):
-    queue_index = int(queue_index)
+def started_jobs(request: HttpRequest, queue_index: int) -> HttpResponse:
     queue = get_queue_by_index(queue_index)
 
     registry = StartedJobRegistry(queue.name, queue.connection)
@@ -208,7 +202,7 @@ def started_jobs(request, queue_index):
             composite_keys = registry.get_job_and_execution_ids(offset, offset + items_per_page - 1)
         except AttributeError:
             composite_keys = [
-                cast(Tuple[str, str], key.split(':'))
+                cast(tuple[str, str], key.split(':'))
                 for key in registry.get_job_ids(offset, offset + items_per_page - 1)
             ]
 
@@ -234,8 +228,7 @@ def started_jobs(request, queue_index):
 
 @never_cache
 @staff_member_required
-def workers(request, queue_index):
-    queue_index = int(queue_index)
+def workers(request: HttpRequest, queue_index: int) -> HttpResponse:
     queue = get_queue_by_index(queue_index)
     clean_worker_registry(queue)
     all_workers = Worker.all(queue.connection)
@@ -252,8 +245,7 @@ def workers(request, queue_index):
 
 @never_cache
 @staff_member_required
-def worker_details(request, queue_index, key):
-    queue_index = int(queue_index)
+def worker_details(request: HttpRequest, queue_index: int, key: str) -> HttpResponse:
     queue = get_queue_by_index(queue_index)
     worker = Worker.find_by_key(key, connection=queue.connection)
     assert worker
@@ -276,8 +268,7 @@ def worker_details(request, queue_index, key):
 
 @never_cache
 @staff_member_required
-def deferred_jobs(request, queue_index):
-    queue_index = int(queue_index)
+def deferred_jobs(request: HttpRequest, queue_index: int) -> HttpResponse:
     queue = get_queue_by_index(queue_index)
 
     registry = DeferredJobRegistry(queue.name, queue.connection)
@@ -322,14 +313,13 @@ def deferred_jobs(request, queue_index):
 
 @never_cache
 @staff_member_required
-def job_detail(request, queue_index, job_id):
-    queue_index = int(queue_index)
+def job_detail(request: HttpRequest, queue_index: int, job_id: str) -> HttpResponse:
     queue = get_queue_by_index(queue_index)
 
     try:
         job = Job.fetch(job_id, connection=queue.connection, serializer=queue.serializer)
     except NoSuchJobError:
-        raise Http404("Couldn't find job with this ID: %s" % job_id)
+        raise Http404(f"Couldn't find job with this ID: {job_id}")
 
     try:
         job.func_name
@@ -349,10 +339,10 @@ def job_detail(request, queue_index, job_id):
 
     dependencies = []
     # if job._dependency_ids:
-        # Fetch dependencies if they exist
-        # dependencies = Job.fetch_many(
-        #     job._dependency_ids, connection=queue.connection, serializer=queue.serializer
-        # )
+    # Fetch dependencies if they exist
+    # dependencies = Job.fetch_many(
+    #     job._dependency_ids, connection=queue.connection, serializer=queue.serializer
+    # )
     for dependency_id in job._dependency_ids:
         try:
             dependency = Job.fetch(dependency_id, connection=queue.connection, serializer=queue.serializer)
@@ -374,8 +364,7 @@ def job_detail(request, queue_index, job_id):
 
 @never_cache
 @staff_member_required
-def delete_job(request, queue_index, job_id):
-    queue_index = int(queue_index)
+def delete_job(request: HttpRequest, queue_index: int, job_id: str) -> HttpResponse:
     queue = get_queue_by_index(queue_index)
     job = Job.fetch(job_id, connection=queue.connection, serializer=queue.serializer)
 
@@ -383,7 +372,7 @@ def delete_job(request, queue_index, job_id):
         # Remove job id from queue and delete the actual job
         queue.connection.lrem(queue.key, 0, job.id)
         job.delete()
-        messages.info(request, 'You have successfully deleted %s' % job.id)
+        messages.info(request, f'You have successfully deleted {job.id}')
         return redirect('rq_jobs', queue_index)
 
     context_data = {
@@ -397,14 +386,13 @@ def delete_job(request, queue_index, job_id):
 
 @never_cache
 @staff_member_required
-def requeue_job_view(request, queue_index, job_id):
-    queue_index = int(queue_index)
+def requeue_job_view(request: HttpRequest, queue_index: int, job_id: str) -> HttpResponse:
     queue = get_queue_by_index(queue_index)
     job = Job.fetch(job_id, connection=queue.connection, serializer=queue.serializer)
 
     if request.method == 'POST':
         requeue_job(job_id, connection=queue.connection, serializer=queue.serializer)
-        messages.info(request, 'You have successfully requeued %s' % job.id)
+        messages.info(request, f'You have successfully requeued {job.id}')
         return redirect('rq_job_detail', queue_index, job_id)
 
     context_data = {
@@ -418,27 +406,12 @@ def requeue_job_view(request, queue_index, job_id):
 
 @never_cache
 @staff_member_required
-def clear_queue(request, queue_index):
-    queue_index = int(queue_index)
+def clear_queue(request: HttpRequest, queue_index: int) -> HttpResponse:
     queue = get_queue_by_index(queue_index)
 
     if request.method == 'POST':
-        try:
-            queue.empty()
-            messages.info(request, 'You have successfully cleared the queue %s' % queue.name)
-        except ResponseError as e:
-            try:
-                suppress = 'EVALSHA' in e.message  # type: ignore[attr-defined]
-            except AttributeError:
-                suppress = 'EVALSHA' in str(e)
-
-            if suppress:
-                messages.error(
-                    request,
-                    'This action is not supported on Redis versions < 2.6.0, please use the bulk delete command instead',
-                )
-            else:
-                raise e
+        queue.empty()
+        messages.info(request, f'You have successfully cleared the queue {queue.name}')
         return redirect('rq_jobs', queue_index)
 
     context_data = {
@@ -451,8 +424,7 @@ def clear_queue(request, queue_index):
 
 @never_cache
 @staff_member_required
-def requeue_all(request, queue_index):
-    queue_index = int(queue_index)
+def requeue_all(request: HttpRequest, queue_index: int) -> HttpResponse:
     queue = get_queue_by_index(queue_index)
     registry = FailedJobRegistry(queue=queue)
 
@@ -482,8 +454,7 @@ def requeue_all(request, queue_index):
 
 @never_cache
 @staff_member_required
-def delete_failed_jobs(request, queue_index):
-    queue_index = int(queue_index)
+def delete_failed_jobs(request: HttpRequest, queue_index: int) -> HttpResponse:
     queue = get_queue_by_index(queue_index)
     registry = FailedJobRegistry(queue=queue)
 
@@ -511,8 +482,7 @@ def delete_failed_jobs(request, queue_index):
 
 @never_cache
 @staff_member_required
-def confirm_action(request, queue_index):
-    queue_index = int(queue_index)
+def confirm_action(request: HttpRequest, queue_index: int) -> HttpResponse:
     queue = get_queue_by_index(queue_index)
     next_url = request.META.get('HTTP_REFERER') or reverse('rq_jobs', args=[queue_index])
 
@@ -534,8 +504,7 @@ def confirm_action(request, queue_index):
 
 @never_cache
 @staff_member_required
-def actions(request, queue_index):
-    queue_index = int(queue_index)
+def actions(request: HttpRequest, queue_index: int) -> HttpResponse:
     queue = get_queue_by_index(queue_index)
     next_url = request.POST.get('next_url') or reverse('rq_jobs', args=[queue_index])
 
@@ -550,7 +519,7 @@ def actions(request, queue_index):
                     # Remove job id from queue and delete the actual job
                     queue.connection.lrem(queue.key, 0, job.id)
                     job.delete()
-                messages.info(request, 'You have successfully deleted %s jobs!' % len(job_ids))
+                messages.info(request, f'You have successfully deleted {len(job_ids)} jobs!')
             elif request.POST['action'] == 'requeue':
                 for job_id in job_ids:
                     requeue_job(job_id, connection=queue.connection, serializer=queue.serializer)
@@ -567,9 +536,8 @@ def actions(request, queue_index):
 
 @never_cache
 @staff_member_required
-def enqueue_job(request, queue_index, job_id):
+def enqueue_job(request: HttpRequest, queue_index: int, job_id: str) -> HttpResponse:
     """Enqueue deferred jobs"""
-    queue_index = int(queue_index)
     queue = get_queue_by_index(queue_index)
     job = Job.fetch(job_id, connection=queue.connection, serializer=queue.serializer)
 
@@ -593,7 +561,7 @@ def enqueue_job(request, queue_index, job_id):
             registry = ScheduledJobRegistry(queue.name, queue.connection)
             registry.remove(job)
 
-        messages.info(request, 'You have successfully enqueued %s' % job.id)
+        messages.info(request, f'You have successfully enqueued {job.id}')
         return redirect('rq_job_detail', queue_index, job_id)
 
     context_data = {
@@ -608,22 +576,21 @@ def enqueue_job(request, queue_index, job_id):
 @never_cache
 @staff_member_required
 @require_POST
-def stop_job(request, queue_index, job_id):
+def stop_job(request: HttpRequest, queue_index: int, job_id: str) -> HttpResponse:
     """Stop started job"""
-    queue_index = int(queue_index)
     queue = get_queue_by_index(queue_index)
     stopped, _ = stop_jobs(queue, job_id)
     if len(stopped) == 1:
-        messages.info(request, 'You have successfully stopped %s' % job_id)
+        messages.info(request, f'You have successfully stopped {job_id}')
         return redirect('rq_job_detail', queue_index, job_id)
     else:
-        messages.error(request, 'Failed to stop %s' % job_id)
+        messages.error(request, f'Failed to stop {job_id}')
         return redirect('rq_job_detail', queue_index, job_id)
 
 
 @never_cache
 @staff_member_required
-def scheduler_jobs(request, scheduler_index):
+def scheduler_jobs(request: HttpRequest, scheduler_index: int) -> HttpResponse:
     scheduler = get_scheduler_by_index(scheduler_index)
 
     items_per_page = 100
